@@ -16,6 +16,3 @@ for m in __all__:
     exec "from . import %s" % m  #relative import
     #print "Imported %s" % globals().get(m,'')
 
-#used by CreateAllInstances                 
-_InstanceModules = [acting, poking, goaling, needing, traiting, fiating, 
-                    wanting, completing, deeding, arbiting, tasking, serving]
